==> polymer-common-0.9.19+1.21.1-sources.jar: eu/pb4/polymer/common/impl/entity/FakeEntity.java <==
package eu.pb4.polymer.common.impl.entity;

import eu.pb4.polymer.common.impl.CommonImpl;
import eu.pb4.polymer.common.impl.FakeWorld;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1937;
import net.minecraft.class_2487;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_2945;
import net.minecraft.class_3231;
import org.jetbrains.annotations.ApiStatus;

@ApiStatus.Internal
class FakeEntity extends class_1297 {
    public static final class_1297 INSTANCE;
    private FakeEntity(class_1299<?> type, class_1937 world) {
        super(type, world);
    }

    @Override
    protected void method_5693(class_2945.class_9222 builder) {}

    @Override
    protected void method_5749(class_2487 nbt) {

    }

    @Override
    protected void method_5652(class_2487 nbt) {

    }

    @Override
    public class_2596<class_2602> method_18002(class_3231 entityTrackerEntry) {
        return super.method_18002(entityTrackerEntry);
    }

    static {
        FakeEntity entity;
        try {
            entity = new FakeEntity(class_1299.field_6093, FakeWorld.INSTANCE_UNSAFE);
        } catch (Throwable e1) {
            CommonImpl.LOGGER.error("Couldn't initiate base template entity... trying again with a different method.", e1);
            try {
                entity = new FakeEntity(class_1299.field_6093, FakeWorld.INSTANCE_REGULAR);
            } catch (Throwable e2) {
                CommonImpl.LOGGER.error("Couldn't initiate base template entity! It's super bad and it might crash soon!", e2);
                entity = null;
            }
        }
        INSTANCE = entity;
    }
}

==> polymer-common-0.14.1+1.21.9-sources.jar: eu/pb4/polymer/common/impl/entity/FakeEntity.java <==
package eu.pb4.polymer.common.impl.entity;

import eu.pb4.polymer.common.impl.CommonImpl;
import eu.pb4.polymer.common.impl.FakeWorld;
import net.minecraft.class_11368;
import net.minecraft.class_11372;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1299;
import net.minecraft.class_1937;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_2945;
import net.minecraft.class_3218;
import net.minecraft.class_3231;
import org.jetbrains.annotations.ApiStatus;

@ApiStatus.Internal
class FakeEntity extends class_1297 {
    public static final class_1297 INSTANCE;
    private FakeEntity(class_1299<?> type, class_1937 world) {
        super(type, world);
    }

    @Override
    protected void method_5693(class_2945.class_9222 builder) {}

    @Override
    public boolean method_64397(class_3218 world, class_1282 source, float amount) {
        return false;
    }

    @Override
    protected void method_5749(class_11368 view) {

    }

    @Override
    protected void method_5652(class_11372 view) {

    }

    @Override
    public class_2596<class_2602> method_18002(class_3231 entityTrackerEntry) {
        return super.method_18002(entityTrackerEntry);
    }

    static {
        FakeEntity entity;
        try {
            entity = new FakeEntity(class_1299.field_6093, FakeWorld.INSTANCE_UNSAFE);
        } catch (Throwable e1) {
            CommonImpl.LOGGER.error("Couldn't initiate base template entity... trying again with a different method.", e1);
            try {
                entity = new FakeEntity(class_1299.field_6093, FakeWorld.INSTANCE_REGULAR);
            } catch (Throwable e2) {
                CommonImpl.LOGGER.error("Couldn't initiate base template entity! It's super bad and it might crash soon!", e2);
                entity = null;
            }
        }
        INSTANCE = entity;
    }
}
